FinanceGraphs-package: FinanceGraphs: Flexible Graphs for Analysis of Financial Data...

FinanceGraphs-packageR Documentation

FinanceGraphs: Flexible Graphs for Analysis of Financial Data and Time Series

Description

Flexible wrappers around R graphics modules 'dygraphs' https://dygraphs.com/ and 'ggplot2' https://ggplot2.tidyverse.org/ to visualize data commonly found in Financial Studies, with an emphasis on time series. Interactive time series plots include multiple options for incorporating external data such as forecasts and events. Other static plots useful for time series data include an intuitive and generic scatter plotter, a boxplot generator suitable for multiple time series, and event study plotters for time series analysis around sets of dates.

Author(s)

Maintainer: Derek Holmes derek@derekholmes.com [copyright holder]

Authors:

See Also

Useful links:


FinanceGraphs documentation built on June 22, 2026, 5:08 p.m.