Add a synchronizing identifier for dygraphs used in Shiny or Markdown contexts
Source:R/set_constants.R
fg_sync_group.RdSets, gets, or resets a common name to be passed into fgts_dygraph() for synchronization.
Details
Group Synchronization
Use thie to set a common groupname for time scale synchronization (for Markdown or shiny apps), Only set it in the beginning, or when needed, and call with NULL to turn synchronization off.