| fg_tsboxplot | R Documentation |
Plots static summaries of time series in boxplot form.
fg_tsboxplot(indt,title="",xlab="",ylab="",
breaks=c(7,30,90,360), doi="last", normalize="", orderby="",
boxtype= "",
dropset="",hilightcats="",
addline="", #last/mean
facetform="",
ycoord=NULL,trimpctile=0,
legend="insidetop",meltvar="variable",flip=FALSE,ptsize=3)
indt |
Input data.frame with at least one date variable and one or more vategorical variables, if melted. |
title, xlab, ylab |
TItles and Labels |
breaks |
A list or text as follows
|
doi |
Points or segments to overlay with latest observations, or changes since a particular date.
|
normalize |
Normalize data in some way prior to plotting. Choices are
|
orderby |
(Default
|
boxtype |
Formatting of boxplots. If in |
dropset |
String or list with underlying categories to drop from graph |
hilightcats |
String or list of underlying categories to highlight with differnt color in label. |
addline |
in |
facetform |
(Default: "") Any faceting formula which includes text or factor columns in |
ycoord |
(Default NULL) a two element list with limits on y corrdinates |
trimpctile |
(Default 0) trims data before any plotting to fall within |
legend |
(Default |
meltvar |
(Default: |
flip |
(Default |
ptsize |
(Default: 3) Size of points for |
A ggplot2::ggplot() object
fg_tsboxplot(eqtypx,breaks=c(7,30,360),normalize="byvar",hilightcats="QQQ",
title="Equity prices, within ranges")
fg_tsboxplot(narrowbydtstr(eqtypx,"-2y::"),breaks="regm",normalize="byvar",
hilightcats="QQQ",title="Equity prices, in regimes")
fg_tsboxplot(reerdta,breaks=c(0,0.2,0.5,1),doi="last",orderby="value",
boxtype="nowhisker",facetform=". ~ REGION",title="Real Eff. Exch Rates")
fg_tsboxplot(reerdta,breaks=c(0,0.2,0.5,1),doi="last",orderby="value",
addline="last",boxtype="violin",title="Real Eff. Exch Rates (Violin)")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.