get_constants: Maintain Colors

fg_get_aesR Documentation

Maintain Colors

Description

fg_get_aes() gets aethestic data.frame for use in graphs. fg_get_aesstring() takes a column from the data.frame retrieved by fg_get_aes() fg_print_aes_list() prints names of aesthetics used internally in FinanceGraph functions. fg_display_colors() Shows a plot with current colors.

Usage

fg_get_aes(item = "", n_max = NA_integer_, asdataframe = FALSE)

fg_get_aesstring(
  item = "",
  n_max = NA_integer_,
  toget = "value",
  rtnifnotfound = FALSE
)

fg_display_colors(item = "")

fg_print_aes_list(grepstr = "")

Arguments

item

(Default: "") A grep string for categories desired.

n_max

Maximum number of rows or entries to return. Required for Rcolorbrewer color aesthetics

asdataframe

(Default: FALSE) Return dataframe of parameters regardless of type. (See details)

toget

Column in the aes data.frame to paste together as a string.

rtnifnotfound

Return NA_character_ if aes not found

grepstr

narrow list of internal aesthetics sets to functions from grepstr

Value

fg_get_aes() returns data.frame of aesthetics, including sorting columns, help strings, and values, fg_get_aesstring() returns a list with just the character values of the requested aesthetic. fg_print_aes_list() returns a markdown ready character vector of aesthetic names used in each function fg_display_colors() returns a ggplot2::ggplot() object with colors and associated names for an aesthetic name

See Also

fgts_dygraph(), fg_update_aes()

Examples

# Data set, String
head(fg_get_aes("lines"),3)
fg_get_aesstring("lines")
#  Gradient colors are stored in a `data.frame` as in a set of "Blue Greens"
fg_get_aes("espath_gp",asdataframe=TRUE)
# To get the actual colors, we need to know how many:
fg_get_aes("espath_gp",n_max=8)
fg_display_colors("lines")


FinanceGraphs documentation built on June 22, 2026, 5:08 p.m.