| ratings_db | R Documentation |
Ratings changes for a few select sovereigns.
ratings_db
ratings_dbA tibble with 110 observations and 5 columns
Short Credit name for a few countries
Ratings Agency
Rating code for each country specific to each agency
Character indicator if ratings is watch positive or negative
Date of ratings annoucement
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.