| FinanceGraphs-package | R Documentation |
Flexible wrappers around R graphics modules 'dygraphs' https://dygraphs.com/ and 'ggplot2' https://ggplot2.tidyverse.org/ to visualize data commonly found in Financial Studies, with an emphasis on time series. Interactive time series plots include multiple options for incorporating external data such as forecasts and events. Other static plots useful for time series data include an intuitive and generic scatter plotter, a boxplot generator suitable for multiple time series, and event study plotters for time series analysis around sets of dates.
Maintainer: Derek Holmes derek@derekholmes.com [copyright holder]
Authors:
Derek Holmes derek@derekholmes.com [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.