| fg_cut_to_events | R Documentation |
Event Helpers: fg_cut_to_events
fg_cut_to_events(
indta,
ncutsperside = 4,
center = 0,
extend = TRUE,
invert = FALSE
)
indta |
Time series |
ncutsperside |
: Integer with number of colors to use on each side of 'center' |
center |
: String or Double as follows:
|
extend |
Logical (Default: TRUE) to extend data to today ( |
invert |
Use opposite color schemes for data, i.e. "red" for good outcomes |
Always uses first date column and first numeric columns in data. If indta has multiple series, filter them before calling the function.
data.table suitable for passing into fgts_dygraph() via the event_ds parameter
smalldta <- narrowbydtstr(eqtypx[,.(date,IBM,QQQ)],"-2y::")
events <- fg_cut_to_events(consumer_sent,center="zscore")
fgts_dygraph(smalldta,title="With Sentiment ranges",event_ds=events)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.