fg_sync_group: Group Synchronization

fg_sync_groupR Documentation

Group Synchronization

Description

Sets, gets, or resets a common name to be passed into fgts_dygraph() for synchronization.

Usage

fg_sync_group(gpname = "")

Arguments

gpname

A string or NULL

  • gpname=NULL turns off dygraphs synchronization.

  • ⁠gpname=<string>⁠ set the common group to ⁠<string>⁠

  • gpname="" (Default), just returns the current common group name.

Details

Use thie to set a common groupname for time scale synchronization (for Markdown or shiny apps), Only set it in the beginning, or when needed, and call with NULL to turn synchronization off.

Value

current groupname

See Also

fgts_dygraph()

Examples

fg_sync_group()
fg_sync_group("common")
fg_sync_group()
fg_sync_group(NULL)


FinanceGraphs documentation built on June 22, 2026, 5:08 p.m.