| fg_sync_group | R Documentation |
Sets, gets, or resets a common name to be passed into fgts_dygraph() for synchronization.
fg_sync_group(gpname = "")
gpname |
A string or NULL
|
Use thie to set a common groupname for time scale synchronization (for Markdown or shiny apps), Only set it in the beginning, or when needed, and call with NULL to turn synchronization off.
current groupname
fgts_dygraph()
fg_sync_group()
fg_sync_group("common")
fg_sync_group()
fg_sync_group(NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.